4Suite API Documentation: Ft.Xml.Xslt.XPatterns

4Suite™ API Documentation

# ► Module Ft.Xml.Xslt.XPatterns

Implement Patterns according to the XSLT spec

    Copyright 1999-2004 Fourthought, Inc. (USA).
    Detailed license and copyright information: http://4suite.org/COPYRIGHT
    Project home, documentation, distributions: http://4suite.org/

Classes: DocumentNodeTest, IdKeyNodeTest, Pattern, Patterns, PredicatedNodeTest |  |  |  | Globals: AttributeAxis, ChildAxis

## Classes

class DocumentNodeTest

  ### Methods

  __init__(self)
  __repr__(self)
  __str__(self)
  getQuickKey(self, namespaces)
  match(self, context, node, principalType)
class IdKeyNodeTest

  ### Methods

  __init__(self, idOrKey)
  __repr__(self)
  __str__(self)
  getQuickKey(self, namespaces)
  match(self, context, node, principalType)
class Pattern

  ### Methods

  __init__(self, steps)
  __repr__(self)
  __str__(self)
  getQuickKey(self, namespaces)
  getShortcut(self)
  match(self, context, node, dummy=None)
  pprint(self, indent='')
class Patterns

  ### Methods

  __init__(self, patterns)
  __repr__(self)
  __str__(self)
  getShortcuts(self, namespaces)
  match(self, context, node)
  pprint(self, indent='')
class PredicatedNodeTest

  ### Methods

  __init__(self, nodeTest, predicateList)
  __repr__(self)
  __str__(self)
  getQuickKey(self, namespaces)
  match(self, context, node, principalType)

## Globals

AttributeAxis = 2
ChildAxis = 1